#include <SFML/Graphics.hpp>
#include <iostream>
#include <array>
#include "Paddle/Paddle.h"
#include "Ball/Ball.h"
#include "Score/Score.h"
#include "Config.h"

int main()
{

    sf::RenderWindow window(sf::VideoMode(WINDOW_WIDTH, WINDOW_HEIGHT), "InfoSV Pong");

	//Chargement fonte
	sf::Font font;
    if (!font.loadFromFile("res/arial.ttf")) return EXIT_FAILURE;
	//Scores
	std::array<Score,2> scores =
		{
			Score(WINDOW_WIDTH-50,0,font),
			Score(10,WINDOW_HEIGHT-60,font)
		};
	
	//Titre
    sf::Text titre("INFOSV PONG", font, 150);
    titre.setRotation(45);
    titre.setColor(sf::Color(255,255,255,50));
    titre.setPosition(100,-90);
    titre.setStyle(sf::Text::Bold);
	//Paddles
    Paddle top(10);
    Paddle bottom(580);
	//Balle
    Ball ball;

    while (window.isOpen())
    {
		//Evénements
        sf::Event event;
        while (window.pollEvent(event))
        {
            if (event.type == sf::Event::Closed)
            {
                window.close();
            }
            //Déplacement souris->déplacement paddle supérieur
            else if (event.type == sf::Event::MouseMoved)
            {
                top.updatePosition(event.mouseMove.x);
            }
            //Touches directionnelles->déplacement paddle inférieur
            else if (event.type == sf::Event::KeyPressed)
            {
                
                if (event.key.code==sf::Keyboard::Left) bottom.updatePositionDelta(-5);
                else if (event.key.code==sf::Keyboard::Right) bottom.updatePositionDelta(5);
            }
        }
        
		//Mouvement balle
        ball.move();
		//Collision balle-paddles
        if (top.getBoundingBox().intersects(ball.getBoundingBox()) || bottom.getBoundingBox().intersects(ball.getBoundingBox()))
        {
            ball.paddleBounce();
        }
		//Game over
        int out(ball.out());
        if (out>=0)
        {
			scores[out].increment();
            ball.restart();
        }

		//Dessin
        window.clear(sf::Color(214,214,214));
		//Titre
        window.draw(titre);
		//Scores
        for (int i(0); i<2; i++) scores[i].draw(window);
		//Paddles
        top.draw(window);
        bottom.draw(window);
		//Balle
        ball.draw(window);

        window.display();
    }

    return EXIT_SUCCESS;
}
